changeset 300:4133575d83fd

Cleanups, more comments in the code, /clearprots -> /cprots
author Matti Hamalainen <ccr@tnsp.org>
date Thu, 02 Mar 2006 17:13:24 +0000
parents f807316cf9a5
children 6862be713676
files ggrtf-magical.tf ggrtf-misc.tf ggrtf.tf
diffstat 3 files changed, 25 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/ggrtf-magical.tf	Thu Mar 02 00:21:57 2006 +0000
+++ b/ggrtf-magical.tf	Thu Mar 02 17:13:24 2006 +0000
@@ -193,6 +193,20 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Battle targetting and resistances
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+; This code has potential "logic hole", as we have to trust what the MUD
+; tells us is happening, when a blast spell hits target or targets.
+;
+; - Spell name is gotten from hit message, then it is transformed to
+;   damage type.
+; - Area spells produce multiple resistance messages (one per monster),
+;   thus we have to "blindly" assume that it was the previously
+;   assumed spell. This should be the case, unless someone is fucking us up.
+; - The above is mainly the reason we do not check for equivalent
+;   target names. Also, some spells do not give target names at blast hit.
+; - Basically this system can be only confused by feeding arbitrary
+;   invalid input to it, thus a wizard (or player descs etc) could achieve
+;   such effect.
+;
 /def -i prgetspelltype =\
 	/if (regmatch(strcat("^(",gspell_type_mana,")$"),{1})) /return "mana"%;\
 	/elseif (regmatch(strcat("^(",gspell_type_elec,")$"),{1})) /return "elec"%;\
--- a/ggrtf-misc.tf	Thu Mar 02 00:21:57 2006 +0000
+++ b/ggrtf-misc.tf	Thu Mar 02 17:13:24 2006 +0000
@@ -162,6 +162,10 @@
 	/set mcont_st=0%;/set mcont_match=%{mcont_match} %{P1}%;/misc_cpurse
 
 
+;/def -i -ag -msimple -t"The pouch contains:" misc_crpouch1 = /set mpouch_st=1
+;/def -i -ag -E(mpouch_st==1) -mregexp -t"^([0-9]+) ([a-z ]+) \(([0-9]+) power, ([0-9]+) standard, ([0-9]+) poor\)$" misc_crpouch2 =
+	
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Camping
--- a/ggrtf.tf	Thu Mar 02 00:21:57 2006 +0000
+++ b/ggrtf.tf	Thu Mar 02 17:13:24 2006 +0000
@@ -1,8 +1,8 @@
 ;;
 ;; GgrTF v0.5.9.23-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti 'ccr' Hämäläinen (aka Ggr Pupunen)
 ;;
-/set ggrtf_ver=0.5.9.23-svn
+/set ggrtf_ver=0.5.9.24-svn
 ;;
 ;; This triggerset is Free Software distributed under
 ;; GNU General Public License version 2.
@@ -23,9 +23,6 @@
 ;; tweak	- Report prots to 'party report'-channel or tweaker (if remote-emote)
 ;; hopple inquisitively	- GgrTF version reporting
 ;;
-;; /comppath		- Shows current path as compressed
-;; /csavepath <name>	- Save compressed path as BatMUD command-alias by given name.
-;;
 ;; For more information, please read "GgrTF User's Manual".
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -707,6 +704,10 @@
 /def -i -p9999 -mregexp -t"^@?([A-Z][a-z]+) hopples around you inquisitively, all bunny-like\.$" greport_ver =\
 	@@emoteto %{P1} is using GgrTF v%{ggrtf_ver} %{ggrtf_copy} on TinyFugue $[ver()]
 
+/def gver = /return "GgrTF %{ggrtf_ver}"
+
+/def gversion =\
+	/msq GgrTF v%{ggrtf_ver} %{ggrtf_copy}
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Prot triggers and reporting
@@ -731,7 +732,7 @@
 
 
 ;; Reset prots
-/def clearprots =\
+/def cprots =\
 	/msq @{BCgreen}NOTICE!@{n} Clearing status of all prots.%;\
 	/prclearprots %{lst_prots}%;\
 	/prots_get%;/gstatus_update
@@ -1,8 +1,8 @@
 ;;
-;; GgrTF v0.5.9.23-svn - TinyFugue script for BatMUD
+;; GgrTF v0.5.9.24-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti 'ccr' Hämäläinen (aka Ggr Pupunen)
 ;;